import { WebApiClient } from '../web-api/web-api-client';
import { Signable } from '../web-api/api-query';
import { TacSigningProcess, NoAuthSigningProcess, CaseMobileSigningProcess } from './signing-process';
import { FilledSigningObject } from './filled-signing-object';
import { SigningObject } from './signing-object';
/**
 * @export
 * @class RequestSigner
 */
export declare class RequestSigner {
    private client;
    private url;
    /**
     * Creates an instance of RequestSigner.
     * @param {WebApiClient} client
     * @param {string} url
     *
     * @memberOf RequestSigner
     */
    constructor(client: WebApiClient, url: string);
    /**
     * Obtains current signing info with full details from the API.
     * @param {string} signId
     * @param {Signable} order
     *
     * @memberOf RequestSigner
     */
    getSigningInfo: (signId: string, order: Signable) => Promise<FilledSigningObject>;
    /**
     * Starts signing process with TAC (that usually means signing using OneTimePassword from SMS)
     * This method will inform the API that the client will sign using TAC.
     * @param {string} signId
     * @returns {Promise<TacSigningProcess>}
     *
     * @memberOf RequestSigner
     */
    startSigningWithTac: (signId: string) => Promise<TacSigningProcess>;
    /**
     * Starts signing process with CASE_MOBILE (that usually means signing using OneTimePassword from SMS)
     * This method will inform the API that the client will sign using CASE_MOBILE.
     * @param {string} signId
     * @returns {Promise<CaseMobileSigningProcess>}
     *
     * @memberOf RequestSigner
     */
    startSigningWithCaseMobile: (signId: string) => Promise<CaseMobileSigningProcess>;
    /**
     * Starts signing process with NO_AUTHORIZATION (that usually means signing the order just by clicking some button in UI)
     * This method signalizes the intent to the API that this order will be signed using NO_AUTHORIZATION method
     * @param {string} signId
     * @returns {Promise<NoAuthSigningProcess>}
     *
     * @memberOf RequestSigner
     */
    startSigningWithNoAuthorization: (signId: string) => Promise<NoAuthSigningProcess>;
    /**
     * Finishes signing process with TAC (that usually means signing using OneTimePassword from SMS)
     * You can call this method only if you successfully called `startSigningWithTAC` before.
     * @param {string} oneTimePassword
     * @param {string} signId
     * @returns {Promise<SigningObject>}
     *
     * @memberOf RequestSigner
     */
    finishSigningWithTac: (oneTimePassword: string, signId: string) => Promise<SigningObject>;
    /**
     * Finishes signing process with CASE_MOBILE (that usually means signing using OneTimePassword from SMS)
     * You can call this method only if you successfully called `startSigningWithCaseMobile` before.
     * @param {string} oneTimePassword
     * @param {string} signId
     * @returns {Promise<SigningObject>}
     *
     * @memberOf RequestSigner
     */
    finishSigningWithCaseMobile: (oneTimePassword: string, signId: string) => Promise<SigningObject>;
    /**
     * This method signalizes the API that the user confirmed signing the order by consent (usually by clicking some button in the UI).
     * You can call this method only if you successfully called `startSigningWithNoAuthorization` before.
     * @param {string} signId
     * @returns {Promise<SigningObject>}
     *
     * @memberOf RequestSigner
     */
    finishSigningWithNoAuth: (signId: string) => Promise<SigningObject>;
}
