import { InstanceResource } from './instance-resource';
import { Paginated, ListResponse, PaginatedListResponse } from './lists';
import { SigningObject } from '../signing/signing-object';
/**
 * Marks Resource or Entity that supports .get Verb.
 * @export
 * @interface GetEnabled
 * @template TResponse
 */
export interface GetEnabled<TResponse> {
    /**
     * Makes a GET call to WebApi and returns a `TResponse` back.
     * @returns {Promise<TResponse>}
     *
     * @memberOf GetEnabled
     */
    get: () => Promise<TResponse>;
}
/**
 * Marks Resource or Entity that supports .get verb with parameters.
 * @export
 * @interface ParametrizedGetEnabled
 * @template TParameters
 * @template TResponse
 */
export interface ParametrizedGetEnabled<TParameters, TResponse> {
    /**
     * Makes a GET call to WebApi and returns a `TResponse` back.
     * @param {TParameters} parameters
     * @returns {Promise<TResponse>}
     *
     * @memberOf ParametrizedGetEnabled
     */
    get: (parameters: TParameters) => Promise<TResponse>;
}
/**
 * Marks Resource or Entity that returns InstanceResource through .withId call
 * @export
 * @interface HasInstanceResource
 * @template T
 */
export interface HasInstanceResource<T extends InstanceResource> {
    /**
     * Get an instance resource with a given id.
     * note: This method does not make any calls to the WebApi by itself.
     * Use  other methods, such as `.get()` on the returned `InstanceResource` to make the call.
     * @param {any} id
     * @returns {T}
     *
     * @memberOf HasInstanceResource
     */
    withId: (id: any) => T;
}
/**
 * Marks Resource or Entity that supports .create verb
 * @export
 * @interface CreateEnabled
 * @template TRequest
 * @template TResponse
 */
export interface CreateEnabled<TRequest, TResponse> {
    /**
     * Makes a POST call to WebApi and returns a `TResponse` returned from server.
     * @param {TRequest} request
     * @returns {Promise<TResponse>}
     *
     * @memberOf CreateEnabled
     */
    create: (request: TRequest) => Promise<TResponse>;
}
/**
 * Marks Resource or Entity that supports .create verb without body payload
 * @export
 * @interface EmptyCreateEnabled
 * @template TResponse
 */
export interface EmptyCreateEnabled<TResponse> {
    /**
     * Makes a POST call to WebApi and returns a `TResponse` returned from server.
     * @returns {Promise<TResponse>}
     *
     * @memberOf EmptyCreateEnabled
     */
    create: () => Promise<TResponse>;
}
/**
 * Marks Resource or Entity that supports .update verb
 * @export
 * @interface UpdateEnabled
 * @template TRequest
 * @template TResponse
 */
export interface UpdateEnabled<TRequest, TResponse> {
    /**
     * @param {TRequest} request
     * @returns {Promise<TResponse>}
     *
     * @memberOf UpdateEnabled
     */
    update: (request: TRequest) => Promise<TResponse>;
}
/**
 * Marks Resource or Entity that supports .update verb without any parameters
 * @export
 * @interface EmptyUpdateEnabled
 * @template TResponse
 */
export interface EmptyUpdateEnabled<TResponse> {
    /**
     * @param {TResponse} request
     * @returns {Promise<TResponse>}
     *
     * @memberOf EmptyUpdateEnabled
     */
    update: (request: TResponse) => Promise<TResponse>;
}
/**
 * Marks Resource or Entity that supports .delete verb
 * @export
 * @interface DeleteEnabled
 * @template TResponse
 */
export interface DeleteEnabled<TResponse> {
    /**
     * @returns {Promise<TResponse>}
     *
     * @memberOf DeleteEnabled
     */
    delete: () => Promise<TResponse>;
}
/**
 * Marks Resource or Entity that supports .delete with query parameters
 * @export
 * @interface ParametrizedDeleteEnabled
 * @template TParameters
 * @template TResponse
 */
export interface ParametrizedDeleteEnabled<TParameters, TResponse> {
    /**
     * @param {TParameters}
     * @returns {Promise<TResponse>}
     *
     * @memberOf ParametrizedDeleteEnabled
     */
    delete: (parameters: TParameters) => Promise<TResponse>;
}
/**
 * Marks Resource or Entity that supports .list verb
 * @export
 * @interface ListEnabled
 * @template TItem
 */
export interface ListEnabled<TItem> {
    /**
     * @returns {Promise<ListResponse<TItem>>}
     *
     * @memberOf ListEnabled
     */
    list: () => Promise<ListResponse<TItem>>;
}
/**
 * Marks Resource or Entity that supports .list verb with parameters
 * @export
 * @interface ParametrizedListEnabled
 * @template TParameters
 * @template TItem
 */
export interface ParametrizedListEnabled<TParameters, TItem> {
    /**
     * @param {TParameters} parameters
     * @returns {Promise<ListResponse<TItem>>}
     *
     * @memberOf ParametrizedListEnabled
     */
    list: (parameters: TParameters) => Promise<ListResponse<TItem>>;
}
/**
 * Marks Resource or Entity that supports .list verb with parameters and pagination
 * @export
 * @interface PaginatedListEnabled
 * @template TItem
 */
export interface PaginatedListEnabled<TItem> {
    list: (parameters: Paginated) => Promise<PaginatedListResponse<TItem>>;
}
/**
 * Marks Resource or Entity that supports .url verb
 * @export
 * @interface HasUrl
 */
export interface HasUrl {
    /**
     * @returns {string}
     *
     * @memberOf HasUrl
     */
    url: () => string;
}
/**
 * Marks Resource or Entity that supports .url verb with parameters
 * @export
 * @interface HasParametrizedUrl
 * @template TParameters
 */
export interface HasParametrizedUrl<TParameters> {
    /**
     * @param {TParameters} parameters
     * @returns {string}
     *
     * @memberOf HasParametrizedUrl
     */
    url: (parameters: TParameters) => string;
}
/**
 * Response with no body.
 *
 * @export
 * @interface EmptyResponse
 */
export interface EmptyResponse {
}
/**
 * Marks response that is signable. It has SigningObject with key signing available.
 * @export
 * @interface Signable
 */
export interface Signable {
    signing: SigningObject;
}
/**
 * Marks Resource or Entity that supports .download verb.
 * @interface DownloadEnabled
 */
export interface DownloadEnabled<TResponse> {
    /**
     * @returns {Promise<TResponse>}
     */
    download: () => Promise<TResponse>;
}
/**
 * Marks Resource or Entity that supports .download verb with parameters.
 * @interface ParametrizedDownloadEnabled
 */
export interface ParametrizedDownloadEnabled<TParameters, TResponse> {
    /**
     * @param {TParameters} parameters
     * @returns {Promise<TResponse>}
     */
    download: (parameters: TParameters) => Promise<TResponse>;
}
/**
 * Marks Resource or Entity that supports .export verb.
 * @interface ExportEnabled
 */
export interface ExportEnabled<TResponse> {
    /**
     * @returns {Promise<TResponse>}
     */
    export: () => Promise<TResponse>;
}
/**
 * Marks Resource or Entity that supports .export verb with parameters.
 * @interface ParametrizedExportEnabled
 */
export interface ParametrizedExportEnabled<TParameters, TResponse> {
    /**
     * @param {TParameters} parameters
     * @returns {Promise<TResponse>}
     */
    export: (parameters: TParameters) => Promise<TResponse>;
}
